BaseComparator class

Implemented types

Constructors

BaseComparator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

different(dynamic a, dynamic b) bool
override
listEquals<T>(List<T> a, List<T> b) bool
override
mapEquals<K, V>(Map<K, V> a, Map<K, V> b) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited