BaseCopier class

Implemented types

Constructors

BaseCopier()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy(Object? object) → dynamic
override
copyList<T>(List array) List<T>
override
copyMap<K, V>(Mapping dict) Map<K, V>
override
deepCopy(Object? object) → dynamic
override
deepCopyList<T>(List array) List<T>
override
deepCopyMap<K, V>(Mapping dict) Map<K, V>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited