operator == method

  1. @override
bool operator ==(
  1. Object other
)
override

The equality operator.

The default behavior for all Objects is to return true if and only if this object and other are the same object.

Override this method to specify a different equality relation on a class. The overriding method must still be an equivalence relation. That is, it must be:

  • Total: It must return a boolean for all arguments. It should never throw.

  • Reflexive: For all objects o, o == o must be true.

  • Symmetric: For all objects o1 and o2, o1 == o2 and o2 == o1 must either both be true, or both be false.

  • Transitive: For all objects o1, o2, and o3, if o1 == o2 and o2 == o3 are true, then o1 == o3 must be true.

The method should also be consistent over time, so whether two objects are equal should only change if at least one of the objects was modified.

If a subclass overrides the equality operator, it should override the hashCode method as well to maintain consistency.

Implementation

@override
bool operator ==(Object other) {
  if (identical(this, other)) {
    // same object
    return true;
  } else if (other is BaseData) {
    // compare as base data
    return _dataEquals(this, other);
  } else if (other is TransportableData) {
    // compare as ted
    return _tedEquals(this, other);
  } else if (other is Stringer) {
    // compare with inner string
    return other.toString() == toString();
  }
  return other is String && other == toString();
}