BaseMeta class abstract

User/Group Meta data

This class is used to generate entity meta

 data format: {
     "type"        : i2s(1),         // algorithm version
     "key"         : "{public key}", // PK = secp256k1(SK);
     "seed"        : "moKy",         // user/group name
     "fingerprint" : "..."           // CT = sign(seed, SK);
 }

 algorithm:
     fingerprint = sign(seed, SK);

abstract method: - Address generateAddress(int? network);

Inheritance
Implemented types

Constructors

BaseMeta([Mapping? dict])
BaseMeta.fromType(String type, VerifyKey key, {String? seed, TransportableData? fingerprint})

Properties

entries Iterable<MapEntry<String, dynamic>>
The map entries of this Map.
no setterinherited
fingerprint TransportableData?
Fingerprint to verify ID and public key
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasSeed bool
no setter
isEmpty bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty bool
Whether there is at least one key/value pair in the map.
no setterinherited
isValid bool
Validates the integrity of this metadata.
no setteroverride
keys Iterable<String>
The keys of this Map.
no setterinherited
length int
The number of key/value pairs in the map.
no setterinherited
publicKey VerifyKey
Public key (used for signature)
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed String?
Seed to generate fingerprint
no setteroverride
type String
Meta algorithm version
no setteroverride
values Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<RK, RV>() Map<RK, RV>
Map<String, dynamic>
inherited
checkValid() bool
clear() → void
Removes all entries from the map.
inherited
containsKey(Object? key) bool
Whether this map contains the given key.
inherited
containsValue(Object? value) bool
Whether this map contains the given value.
inherited
copyMap([bool deepCopy = false]) Map<String, dynamic>
Creates a copy of the internal map.
inherited
forEach(void action(String key, dynamic value)) → void
Applies action to each key/value pair of the map.
inherited
generateAddress(int? network) Address
Generates an Address from this metadata for the specified network.
inherited
getBool(String key, [bool? defaultValue]) bool?
inherited
getDateTime(String key, [DateTime? defaultValue]) DateTime?
inherited
getDouble(String key, [double? defaultValue]) double?
inherited
getInt(String key, [int? defaultValue]) int?
inherited
getString(String key, [String? defaultValue]) String?
Gets a string value for the given key.
inherited
map<K2, V2>(MapEntry<K2, V2> convert(String key, dynamic value)) Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
inherited
removeWhere(bool test(String key, dynamic value)) → void
Removes all entries of this map that satisfy the given test.
inherited
setDateTime(String key, DateTime? time) → void
inherited
setMap(String key, Mapper? mapper) → void
inherited
setString(String key, Stringer? stringer) → void
inherited
toMap() MutableMapping
Returns the internal map as a Map.
inherited
toString() String
A string representation of this object.
inherited
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(String key, dynamic value)) → void
Updates all values.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
inherited
operator []=(String key, dynamic value) → void
Associates the key with the given value.
inherited