originalSignature property
String?
get
originalSignature
override
Gets the digital signature of the original message being acknowledged.
Used to verify the authenticity of the original message in the receipt.
Implementation
@override
String? get originalSignature => Converter.getString(origin?['signature']);