CommandFactory class abstract interface

Factory interface for parsing command messages from map objects.

Provides a standardized way to convert raw map data (from JSON) into strongly-typed Command instances.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseCommand(Mapping content) Command?
Parses a map object (from JSON) into a Command instance.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited