QUOTE constant
String
const QUOTE
Quote a message before and reply it with text
Implementation
static const QUOTE = '${0x37}';
Quote a message before and reply it with text
static const QUOTE = '${0x37}';