Converter class final

Data Convert Utilities

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

BOOLEAN_STATES Map<String, bool>
final
converter DataConverter
getter/setter pair
MAX_BOOLEAN_LEN int
getter/setter pair

Static Methods

getBool(Object? value, [bool? defaultValue]) bool?
assume value can be a config string: 'true', 'false', 'yes', 'no', 'on', 'off', '1', '0', ...
getDateTime(Object? value, [DateTime? defaultValue]) DateTime?
assume value can be a timestamp (seconds from 1970-01-01 00:00:00)
getDouble(Object? value, [double? defaultValue]) double?
getInt(Object? value, [int? defaultValue]) int?
getString(Object? value, [String? defaultValue]) String?