Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBool(
Object? value, bool? defaultValue) → bool? -
getDateTime(
Object? value, DateTime? defaultValue) → DateTime? -
getDouble(
Object? value, double? defaultValue) → double? -
getInt(
Object? value, int? defaultValue) → int? -
getString(
Object? value, String? defaultValue) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited