Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMap(
Object? dict) → Map? -
getString(
Object? str) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unwrap(
Object? object) → dynamic -
unwrapList<
T> (List array) → List< T> -
unwrapMap<
K, V> (Mapping dict) → Map< K, V>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited