getString method
Gets a string value for the given key.
Returns the string value associated with key or defaultValue if the key
is not found.
@param key The key to look up.
@param defaultValue The default value to return if the key is not found.
@return The string value or default value.
Implementation
@override
String? getString(String key, [String? defaultValue]) =>
Converter.getString(_map[key], defaultValue);