EntityType class final

@enum MKMEntityType

@abstract A network ID to indicate what kind the entity is.

@discussion An address can identify a person, a group of people, a team, even a thing.

 MKMEntityType_User indicates this entity is a person's account.
 An account should have a public key, which proved by meta data.

 MKMEntityType_Group indicates this entity is a group of people,
 which should have a founder (also the owner), and some members.

 MKMEntityType_Station indicates this entity is a DIM network station.

 MKMEntityType_ISP indicates this entity is a group for stations.

 MKMEntityType_Bot indicates this entity is a bot user.

 MKMEntityType_Company indicates a company for stations and/or bots.

Bits: 0000 0001 - group flag 0000 0010 - node flag 0000 0100 - bot flag 0000 1000 - CA flag ... (reserved) 0100 0000 - customized flag 1000 0000 - broadcast flag

 (All above are just some advices to help choosing numbers :P)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isBroadcast(int network) bool
isGroup(int network) bool
isUser(int network) bool

Constants

ANY → const int
Broadcast: 128, 129
BOT → const int
Bot: 4, 5
EVERY → const int
GROUP → const int
ICP → const int
ISP → const int
STATION → const int
Network: 2, 3
USER → const int
Main: 0, 1