type property

  1. @override
String? get type
override

Message content type identifier (for routing encrypted content).

Purpose: Since message content may be encrypted, intermediate nodes (e.g., stations) cannot parse the content to determine its type. This field exposes the content type in plaintext to enable proper routing/processing by network nodes.

Examples: "text", "file", "command", ...

Implementation

@override
String? get type => getString('type');
  1. @override
set type (String? msgType)
override

Implementation

@override
set type(String? msgType) => this['type'] = msgType;