MetaFactory class abstract interface

Factory interface for creating and parsing Meta instances.

Provides methods to create metadata from raw components, generate valid metadata (with proper fingerprint), and parse serialized metadata.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createMeta(VerifyKey pKey, {String? seed, TransportableData? fingerprint}) Meta
Creates a Meta instance from explicit components.
generateMeta(SignKey sKey, {String? seed}) Meta
Generates a valid Meta instance with a proper fingerprint.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseMeta(Mapping meta) Meta?
Parses a serialized Map into a Meta instance.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited