PublicKeyFactory class abstract interface

Factory interface for parsing PublicKey instances from serialized data.

Provides methods to reconstruct public keys from their serialized representation.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parsePublicKey(Mapping key) PublicKey?
Parses a serialized Map into a PublicKey instance.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited