text property
String
get
text
Gets the reply text content of the quote message.
This is the user's new commentary/response to the original quoted message.
Implementation
String get text;
Gets the reply text content of the quote message.
This is the user's new commentary/response to the original quoted message.
String get text;