originalSignature property

String? get originalSignature

Gets the digital signature of the original message being acknowledged.

Used to verify the authenticity of the original message in the receipt.

Implementation

String? get originalSignature;