PLAIN constant
String
const PLAIN
Symmetric key algorithm for broadcast message, which will do nothing when en/decoding message data
Implementation
static const PLAIN = 'PLAIN';
Symmetric key algorithm for broadcast message, which will do nothing when en/decoding message data
static const PLAIN = 'PLAIN';