generateSymmetricKey abstract method

SymmetricKey? generateSymmetricKey(
  1. String algorithm
)

Generates a new symmetric key for the specified algorithm.

Creates a cryptographically secure random key for the given algorithm.

@param algorithm - Name of the symmetric algorithm (e.g., "AES")

@return New symmetric key (null if algorithm is unsupported)

Implementation

SymmetricKey? generateSymmetricKey(String algorithm);