TransportableFileHelper class abstract interface

Helper interface for creating/parsing TransportableFile instances.

Provides factory methods to abstract the creation logic of TransportableFile implementations.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTransportableFile(TransportableData? data, String? filename, Uri? url, DecryptKey? password) TransportableFile
Creates a TransportableFile instance with the given metadata.
getTransportableFileFactory() TransportableFileFactory?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseTransportableFile(Object? pnf) TransportableFile?
Parses a raw object into a TransportableFile instance.
setTransportableFileFactory(TransportableFileFactory factory) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited