Wrapper class final

Data Wrap Utilities

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

wrapper DataWrapper
getter/setter pair

Static Methods

getMap(Object? dict) Map?
Get inner Map
getString(Object? str) String?
Get inner String
unwrap(Object? object) → dynamic
Unwrap recursively
unwrapList<T>(List array) List<T>
Unwrap values in the array
unwrapMap<K, V>(Mapping dict) Map<K, V>
Unwrap values for keys in map