BaseWrapper class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMap(
Object? dict) → Map? -
override
-
getString(
Object? str) → String? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unwrap(
Object? object) → dynamic -
override
-
unwrapList<
T> (List array) → List< T> -
override
-
unwrapMap<
K, V> (Mapping dict) → Map< K, V> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited