ContentType class final
@enum ContentType
@abstract A flag to indicate what kind of message content this is.
@discussion A message is something send from one place to another one, it can be an instant message, a system command, or something else.
ContentType_Text indicates this is a normal message with plaintext.
ContentType_File indicates this is a file, it may include filename
and file data, but usually the file data will encrypted and upload to
somewhere and here is just a URL to retrieve it.
ContentType_Image indicates this is an image, it may send the image
data directly(encode the image data with Base64), but we suggest to
include a URL for this image just like the 'File' message, of course
you can get a thumbnail of this image here.
ContentType_Audio indicates this is a voice message, you can get
a URL to retrieve the voice data just like the 'File' message.
ContentType_Video indicates this is a video file.
ContentType_Page indicates this is a web page.
ContentType_Quote indicates this message has quoted another message
and the message content should be a plaintext.
ContentType_Command indicates this is a command message.
ContentType_Forward indicates here contains a TOP-SECRET message
which needs your help to redirect it to the true receiver.
Bits: 0000 0001 - this message contains plaintext you can read. 0000 0010 - this is a message you can see. 0000 0100 - this is a message you can hear. 0000 1000 - this is a message for the bot, not for human.
0001 0000 - this message's main part is in somewhere else.
0010 0000 - this message contains the 3rd party content.
0100 0000 - this message contains digital assets
1000 0000 - this is a message send by the system, not human.
(All above are just some advices to help choosing numbers :P)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ANY → const String
- APPLICATION → const String
- Application Customized
- ARRAY → const String
- AUDIO → const String
- CLAIM_PAYMENT → const String
- COMBINE_FORWARD → const String
- COMMAND → const String
- CUSTOMIZED → const String
- FILE → const String
- FORWARD → const String
- Top-Secret message forward by proxy (MTA)
- HISTORY → const String
- IMAGE → const String
- LUCKY_MONEY → const String
- MONEY → const String
- NAME_CARD → const String
- Name Card
- PAGE → const String
- Web Page
- QUOTE → const String
- Quote a message before and reply it with text
- SPLIT_BILL → const String
- TEXT → const String
- TRANSFER → const String
- VIDEO → const String