Interface for encoding/decoding binary data to/from string representations.
Supported encoding types include (but are not limited to):
- Hex (hexadecimal)
- Base58
- Base64
Core functionality:
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
String string) → Uint8List? - Decodes a string back to binary data.
-
encode(
Uint8List data) → String - Encodes binary data to a string representation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited