Factory interface for creating and parsing Document instances.
Provides methods to create new documents (empty or from existing data) and parse serialized documents from structured data.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createDocument(
{String? data, TransportableData? signature}) → Document - Creates a Document instance from data and signature.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseDocument(
Mapping doc) → Document? - Parses a serialized Map into a Document instance.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited