Interface for computing cryptographic hashes (message digests) of binary data.
Supported hash algorithms include (but are not limited to):
- MD5
- SHA-1
- SHA-256
- Keccak-256
- RipeMD-160
A message digest is a fixed-size string of bytes derived from arbitrary-sized input data, used for data integrity verification.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
digest(
Uint8List data) → Uint8List - Computes the cryptographic hash (digest) of the given binary data.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited