Interface for immutable metadata of network entities (users/groups).
Meta data contains core, unchanging information used to validate entities and generate their addresses/IDs. It implements Mapper for serialization to/from structured formats (Map/JSON).
Serialized format (Map/JSON):
{
"type" : "1", // Algorithm version
"key" : "{public key}", // Public key: PK = secp256k1(SK)
"seed" : "moKy", // Entity name (seed for fingerprint)
"fingerprint" : "..." // Signature of seed: CT = sign(seed, SK)
}
Core algorithm:
- Fingerprint = sign(seed, private key)
- Used to verify the authenticity of the entity's name and public key
Properties
-
entries
→ Iterable<
MapEntry< String, dynamic> > -
The map entries of this Map.
no setterinherited
- fingerprint → TransportableData?
-
Fingerprint to verify ID and public key
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setterinherited
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
- isValid → bool
-
Validates the integrity of this metadata.
no setter
-
keys
→ Iterable<
String> -
The keys of this Map.
no setterinherited
- length → int
-
The number of key/value pairs in the map.
no setterinherited
- publicKey → VerifyKey
-
Public key (used for signature)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → String?
-
Seed to generate fingerprint
no setter
- type → String
-
Meta algorithm version
no setter
- values → Iterable
-
The values of this Map.
no setterinherited
Methods
-
addAll(
Map< String, dynamic> other) → void -
Adds all key/value pairs of
otherto this map.inherited -
addEntries(
Iterable< MapEntry< newEntries) → voidString, dynamic> > -
Adds all key/value pairs of
newEntriesto this map.inherited -
cast<
RK, RV> () → Map< RK, RV> -
Provides a view of this map as having
RKkeys andRVinstances, if necessary.inherited -
clear(
) → void -
Removes all entries from the map.
inherited
-
containsKey(
Object? key) → bool -
Whether this map contains the given
key.inherited -
containsValue(
Object? value) → bool -
Whether this map contains the given
value.inherited -
copyMap(
[bool deepCopy = false]) → Map< String, dynamic> -
Creates a copy of the internal map.
inherited
-
forEach(
void action(String key, dynamic value)) → void -
Applies
actionto each key/value pair of the map.inherited -
generateAddress(
int? network) → Address - Generates an Address from this metadata for the specified network.
-
getBool(
String key, [bool? defaultValue]) → bool? -
inherited
-
getDateTime(
String key, [DateTime? defaultValue]) → DateTime? -
inherited
-
getDouble(
String key, [double? defaultValue]) → double? -
inherited
-
getInt(
String key, [int? defaultValue]) → int? -
inherited
-
getString(
String key, [String? defaultValue]) → String? -
Gets a string value for the given key.
inherited
-
map<
K2, V2> (MapEntry< K2, V2> convert(String key, dynamic value)) → Map<K2, V2> -
Returns a new map where all entries of this map are transformed by
the given
convertfunction.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putIfAbsent(
String key, dynamic ifAbsent()) → dynamic -
Look up the value of
key, or add a new entry if it isn't there.inherited -
remove(
Object? key) → dynamic -
Removes
keyand its associated value, if present, from the map.inherited -
removeWhere(
bool test(String key, dynamic value)) → void -
Removes all entries of this map that satisfy the given
test.inherited -
setDateTime(
String key, DateTime? time) → void -
inherited
-
setMap(
String key, Mapper? mapper) → void -
inherited
-
setString(
String key, Stringer? stringer) → void -
inherited
-
toMap(
) → MutableMapping -
Returns the internal map as a Map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic -
Updates the value for the provided
key.inherited -
updateAll(
dynamic update(String key, dynamic value)) → void -
Updates all values.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → dynamic -
The value for the given
key, ornullifkeyis not in the map.inherited -
operator []=(
String key, dynamic value) → void -
Associates the
keywith the givenvalue.inherited
Static Methods
-
create(
String type, VerifyKey pKey, {String? seed, TransportableData? fingerprint}) → Meta - Create from stored info
-
generate(
String type, SignKey sKey, {String? seed}) → Meta - Generate with private key
-
getFactory(
String type) → MetaFactory? -
parse(
Object? meta) → Meta? -
setFactory(
String type, MetaFactory factory) → void