isValid property
bool
get
isValid
Validates the integrity of this metadata.
Important: Must be called when receiving new metadata from the network to verify the fingerprint matches the seed and public key.
Returns: true if fingerprint is valid (signature matches seed and public key), false otherwise (invalid or tampered metadata)
Implementation
bool get isValid;