query static method
Creates a query meta command to request entity metadata.
Use this to ask for metadata of a specific entity (meta field will be null).
@param did - Target entity ID (user/group ID) to query
@return A MetaCommand instance for metadata query
Implementation
static MetaCommand query(ID did) =>
BaseMetaCommand.fromCmd(Command.META, did, null);