MetaType class final
@enum MetaType
@abstract Defined for algorithm that generating address.
@discussion Generate and check ID/Address
MetaType_MKM give a seed string first, and sign this seed to get
fingerprint; after that, use the fingerprint to generate address.
This will get a firmly relationship between (username, address and key).
MetaType_BTC use the key data to generate address directly.
This can build a BTC address for the entity ID (no username).
MetaType_ExBTC use the key data to generate address directly, and
sign the seed to get fingerprint (just for binding username and key).
This can build a BTC address, and bind a username to the entity ID.
Bits: 0000 0001 - this meta contains seed as ID.name 0000 0010 - this meta generate BTC address 0000 0100 - this meta generate ETH address ...
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited