Helper interface for processing quote/receipt metadata.
Provides methods to purify (normalize) message envelope and content data for QuoteContent (quote reply) and ReceiptCommand (message receipt) scenarios, ensuring consistent structure of the "origin" field in these messages.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
purifyForQuote(
Envelope envelope, Content content) → Map - Purifies message data for use in QuoteContent.
-
purifyForReceipt(
Envelope? envelope, Content? content) → Map? - Purifies message data for use in ReceiptCommand.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited