QuotePurifier class final
Default implementation of QuoteHelper for quote/receipt data purification.
Provides standard logic to extract and normalize origin metadata for quote messages and receipt commands.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
purifyForQuote(
Envelope head, Content body) → Map -
Purifies message data for use in QuoteContent.
override
-
purifyForReceipt(
Envelope? head, Content? body) → Map? -
Purifies message data for use in ReceiptCommand.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited