Helper interface for secure message management.
Manages secure message factories and provides core functionality for:
- Parsing raw secure message data into strongly-typed SecureMessage instances
SecureMessage represents an encrypted message (InstantMessage after encryption) that protects the content from unauthorized access.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSecureMessageFactory(
) → SecureMessageFactory? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseSecureMessage(
Object? msg) → SecureMessage? - Parses raw secure message data into a strongly-typed SecureMessage instance.
-
setSecureMessageFactory(
SecureMessageFactory factory) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited