Interface for encoding/decoding strings to/from binary data (byte arrays).
Supported character encodings include (but are not limited to):
- UTF-8 (default for most applications)
- UTF-16
- GBK
- GB2312
Core functionality:
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
Uint8List data) → String? - Decodes binary data back to a string using the specified character encoding.
-
encode(
String string) → Uint8List - Encodes a string to binary data using the specified character encoding.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited