isValid property
bool
get
isValid
Validates the integrity of this TAI data.
Returns: true if the signature matches the data and entity's public key, false if signature is missing or invalid
Implementation
bool get isValid;