Factory interface for creating TransportableFile (PNF) instances.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createTransportableFile(
TransportableData? data, String? filename, Uri? url, DecryptKey? password) → TransportableFile - Creates a TransportableFile instance with the given parameters.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseTransportableFile(
Mapping pnf) → TransportableFile? - Parses a structured Map into a TransportableFile instance.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited