Factory interface for creating TransportableFileWrapper instances.
Implement this interface to provide custom wrapper implementations (e.g., for different serialization formats).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createTransportableFileWrapper(
Mapping content, {TransportableData? data, String? filename, Uri? url, DecryptKey? password}) → TransportableFileWrapper - Creates a TransportableFileWrapper instance with the given parameters.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited